# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.5.0~42c7d6b',
    built_at='2024-04-02 10:28:56Z',
    sha='42c7d6be0de84cc76d8b2427394325a10142beae',
    branch='HEAD',
    tag='v4.5.0',
)
